@@ -19,10 +19,12 @@ class ReservationTest(ItineraryTestCase):
     def setUp(self):
         # open the timeline page and import test scenario
         self.driver.find_element(by=AppiumBy.NAME, value="Itinerary").click()
-        self.triggerImportAction("Open File…")
+
+        self.driver.find_element(by=AppiumBy.NAME, value="From file").click()
+
         self.openFile("../tests/randa2017.json")
         self.driver.find_element(by=AppiumBy.NAME, value="Import selection").click()
-        self.driver.find_element(by=AppiumBy.NAME, value="Randa (September 2017)").click()
+        self.driver.find_element(by=AppiumBy.NAME, value="MyTrip").click()
 
     def tearDown(self):
         self.driver.find_element(by=AppiumBy.NAME, value="Delete trip").click()
