@@ -529,9 +529,114 @@ bool ApplicationController::exportBatchToFile(const QString &batchId, const QStr
     return true;
 }
 
+void ApplicationController::exportBatchToGpx(const QString &batchId, const QUrl &url)
+{
+    if (url.isEmpty()) {
+        return;
+    }
+
+    QFile f(FileHelper::toLocalFile(url));
+    if (!f.open(QFile::WriteOnly)) {
+        qCWarning(Log) << f.errorString() << f.fileName();
+        Q_EMIT infoMessage(i18n("Export failed: %1", f.errorString()));
+        return;
+    }
+    GpxExport exporter(&f);
+
+    const auto res = m_resMgr->reservation(batchId);
+    const auto transferBefore = m_transferMgr->transfer(batchId, Transfer::Before);
+    const auto transferAfter = m_transferMgr->transfer(batchId, Transfer::After);
+    exporter.writeReservation(res, m_liveDataMgr->journey(batchId), transferBefore, transferAfter);
+
+    Q_EMIT infoMessage(i18n("Export completed."));
+}
+
+void ApplicationController::exportPassToFile(const QString &passId, const QUrl &url)
+{
+    if (url.isEmpty()) {
+        return;
+    }
+    if (exportPassToFile(passId, FileHelper::toLocalFile(url))) {
+        Q_EMIT infoMessage(i18n("Export completed."));
+    }
+}
+
+void ApplicationController::exportPassToKDEConnect(const QString &passId, const QString &deviceId)
+{
+    if (passId.isEmpty() || deviceId.isEmpty()) {
+        return;
+    }
+
+    if (!m_tempDir) {
+        m_tempDir = std::make_unique<QTemporaryDir>();
+    }
+
+    QTemporaryFile f(m_tempDir->path() + QStringLiteral("/XXXXXX.itinerary"));
+    if (!f.open()) {
+        qCWarning(Log) << "Failed to open temporary file:" << f.errorString();
+        Q_EMIT infoMessage(i18n("Export failed: %1", f.errorString()));
+        return;
+    }
+
+    if (exportPassToFile(passId, f.fileName())) {
+        // will be removed by the temporary dir it's in, as we don't know when the upload is done
+        f.setAutoRemove(false);
+        f.close();
+        KDEConnect::sendToDevice(f.fileName(), deviceId);
+    }
+    Q_EMIT infoMessage(i18n("Pass sent."));
+}
+
+bool ApplicationController::exportPassToFile(const QString &passId, const QString &fileName)
+{
+    File f(fileName);
+    if (!f.open(File::Write)) {
+        qCWarning(Log) << f.errorString() << fileName;
+        Q_EMIT infoMessage(i18n("Export failed: %1", f.errorString()));
+        return false;
+    }
+
+    Exporter exporter(&f);
+    exporter.exportPass(passId, m_passMgr);
+
+    const auto pass = m_passMgr->pass(passId);
+    const auto pkPassId = PkPassManager::passId(pass);
+    exporter.exportPkPass(m_pkPassMgr, pkPassId);
+
+    QSet<QString> docIdSet;
+    const auto docIds = DocumentUtil::documentIds(pass);
+    for (const auto &docId : docIds) {
+        const auto id = docId.toString();
+        if (!id.isEmpty() && m_docMgr->hasDocument(id) && !docIdSet.contains(id)) {
+            exporter.exportDocument(m_docMgr, id);
+            docIdSet.insert(id);
+        }
+    }
+    return true;
+}
+
+void ApplicationController::exportPkPassToFile(const QString &passId, const QUrl &url)
+{
+    if (url.isEmpty()) {
+        return;
+    }
+    QFile f(FileHelper::toLocalFile(url));
+    if (!f.open(QFile::WriteOnly | QFile::Truncate)) {
+        Q_EMIT infoMessage(i18n("Saving failed: %1", f.errorString()));
+        return;
+    }
+    f.write(PkPassManager::rawData(passId));
+
+    Q_EMIT infoMessage(i18n("File saved successfully."));
+}
+
 bool ApplicationController::importBundle(KItinerary::File *file)
 {
     Importer importer(file);
+    if (importer.formatVersion() > BUNDLE_FORMAT_VERSION) {
+        Q_EMIT infoMessage(i18n("File was imported with a newer version of Itinerary. Some information might not be imported correctly."));
+    }
+
     int count = 0;
     int settingsCount = 0;
     {
