@@ -87,6 +87,11 @@ public:
     Q_INVOKABLE void exportTripToGpx(const QString &tripGroupId, const QUrl &url);
     Q_INVOKABLE void exportBatchToFile(const QString &batchId, const QUrl &url);
     Q_INVOKABLE void exportBatchToKDEConnect(const QString &batchId, const QString &deviceId);
+    Q_INVOKABLE void exportBatchToGpx(const QString &batchId, const QUrl &url);
+    Q_INVOKABLE void exportPassToFile(const QString &passId, const QUrl &url);
+    Q_INVOKABLE void exportPassToKDEConnect(const QString &passId, const QString &deviceId);
+
+    Q_INVOKABLE void exportPkPassToFile(const QString &passId, const QUrl &url);
 
     // document attaching
     Q_INVOKABLE void addDocumentToReservation(const QString &batchId, const QUrl &url);
@@ -131,6 +136,7 @@ private:
 
     bool exportTripToFile(const QString &tripGroupId, const QString &fileName);
     bool exportBatchToFile(const QString &batchId, const QString &fileName);
+    bool exportPassToFile(const QString &passId, const QString &fileName);
 
     static ApplicationController *s_instance;
 
