@@ -9,7 +9,8 @@
 
 #include <chrono>
 
-namespace Constants {
+namespace Constants
+{
 constexpr std::chrono::seconds MaximumLayoverTime = std::chrono::hours(4);
 constexpr std::chrono::seconds FavoriteLocationAutoTransferThreshold = std::chrono::days(1);
 
