@@ -215,6 +215,14 @@ QVariant PassManager::pass(const QString &passId) const
     return it == m_entries.end() ? QVariant() : (*it).data;
 }
 
+QByteArray PassManager::passData(const QString &passId) const
+{
+    const auto it = std::ranges::find_if(m_entries, [passId](const auto &entry) {
+        return entry.id == passId;
+    });
+    return it != m_entries.end() ? JsonIO::convert(rawData(*it), JsonIO::JSON) : QByteArray();
+}
+
 QVariant PassManager::data(const QModelIndex &index, int role) const
 {
     if (!checkIndex(index)) {
@@ -268,10 +276,10 @@ QVariant PassManager::data(const QModelIndex &index, int role) const
             return QLocale().toString(from.date(), QLocale::ShortFormat);
         }
         if (days >= 28 && days <= 31) {
-            return QLocale().toString(from, QStringLiteral("MMMM yyyy"));
+            return QLocale().toString(from, u"MMMM yyyy");
         }
         if (days >= 365 && days <= 366) {
-            return QLocale().toString(from, QStringLiteral("yyyy"));
+            return QLocale().toString(from, u"yyyy");
         }
         return i18n("%1 - %2", QLocale().toString(from.date(), QLocale::ShortFormat), QLocale().toString(to.date(), QLocale::ShortFormat));
     }
@@ -392,7 +400,7 @@ QVariantList PassManager::documentIds(const QVariant &pass)
 
 QString PassManager::basePath()
 {
-    return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1StringView("/programs/");
+    return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/programs/"_L1;
 }
 
 #include "moc_passmanager.cpp"
