@@ -8,8 +8,8 @@
 #include <QDebug>
 
 #ifdef Q_OS_ANDROID
-#include <KAndroidExtras/ManifestPermission>
 #include "private/qandroidextras_p.h"
+#include <KAndroidExtras/ManifestPermission>
 #endif
 
 #ifdef Q_OS_ANDROID
@@ -17,16 +17,14 @@ static QString permissionName(Permission::Permission p)
 {
     using namespace KAndroidExtras;
     switch (p) {
-        case Permission::InvalidPermission:
-            Q_UNREACHABLE();
-        case Permission::ReadCalendar:
-            return ManifestPermission::READ_CALENDAR;
-        case Permission::WriteCalendar:
-            return ManifestPermission::WRITE_CALENDAR;
-        case Permission::PostNotification:  // only for SDK >= 33
-            return ManifestPermission::POST_NOTIFICATIONS;
-        case Permission::Camera:
-            return ManifestPermission::CAMERA;
+    case Permission::InvalidPermission:
+        Q_UNREACHABLE();
+    case Permission::ReadCalendar:
+        return ManifestPermission::READ_CALENDAR;
+    case Permission::WriteCalendar:
+        return ManifestPermission::WRITE_CALENDAR;
+    case Permission::Camera:
+        return ManifestPermission::CAMERA;
     }
 }
 #endif
@@ -38,10 +36,6 @@ bool PermissionManager::checkPermission(Permission::Permission permission)
         return false;
     }
 #ifdef Q_OS_ANDROID
-    if (permission == Permission::PostNotification && QtAndroidPrivate::androidSdkVersion() < 33) {
-        return true;
-    }
-
     return QtAndroidPrivate::checkPermission(permissionName(permission)).result() == QtAndroidPrivate::PermissionResult::Authorized;
 #else // non-Android
     Q_UNUSED(permission);
