@@ -257,6 +257,9 @@ QVariant PublicTransport::applyJourneySection(const QVariant &res, const KPublic
     if (JsonLd::isA<BoatReservation>(res)) {
         return postProcessOne(::applyJourneySection(res.value<BoatReservation>(), section));
     }
+    if (JsonLd::isA<FlightReservation>(res)) {
+        return postProcessOne(::applyJourneySection(res.value<FlightReservation>(), section));
+    }
 
     qCWarning(Log) << res.typeName() << "Unsupported section type!";
     return res;
@@ -349,11 +352,11 @@ QString PublicTransport::attributionSummary(const QVariantList &attributions) co
     return QLocale().createSeparatedList(l);
 }
 
-QString PublicTransport::idenfitierFromLocation(const KPublicTransport::Location &loc)
+QString PublicTransport::identifierFromLocation(const KPublicTransport::Location &loc)
 {
-    for (const auto &type : { "ibnr", "uic", "iata" }) {
-        if (const auto id = loc.identifier(QLatin1StringView(type)); !id.isEmpty()) {
-            return QLatin1StringView(type) + id;
+    for (const auto &type : { "ibnr"_L1, "uic"_L1, "iata"_L1 }) {
+        if (const auto id = loc.identifier(type); !id.isEmpty()) {
+            return type + ':'_L1 + id;
         }
     }
     return {};
