@@ -5,7 +5,9 @@
 */
 
 #include "reservationhelper.h"
+
 #include "genericpkpass.h"
+#include "reservationmanager.h"
 
 #include <KItinerary/BoatTrip>
 #include <KItinerary/BusTrip>
@@ -14,6 +16,7 @@
 #include <KItinerary/LocationUtil>
 #include <KItinerary/Person>
 #include <KItinerary/Reservation>
+#include <KItinerary/SortUtil>
 #include <KItinerary/Ticket>
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
@@ -43,6 +46,10 @@ std::pair<QString, QString> ReservationHelper::lineNameAndNumber(const QVariant
         const auto flight = res.value<FlightReservation>().reservationFor().value<Flight>();
         return std::make_pair(flight.airline().iataCode(), flight.flightNumber());
     }
+    if (JsonLd::isA<BoatReservation>(res)) {
+        const auto trip = res.value<BoatReservation>().reservationFor().value<BoatTrip>();
+        return std::make_pair(trip.name(), QString());
+    }
 
     return {};
 }
@@ -181,4 +188,36 @@ QString ReservationHelper::defaultIconName(const QVariant &res)
     return {};
 }
 
+QString ReservationHelper::previousBatch(ReservationManager *resMgr, const QString &resId)
+{
+    QString id = resId;
+    QString prevId;
+    QVariant prevRes;
+
+    while (true) {
+        id = resMgr->previousBatch(id);
+        if (id.isEmpty()) {
+            return prevId;
+        }
+        auto res = resMgr->reservation(id);
+
+        if (ReservationHelper::isCancelled(id)) {
+            continue;
+        }
+
+        if (LocationUtil::isLocationChange(res) || !SortUtil::hasEndTime(res)) {
+            return prevId.isEmpty() ? id : prevId;
+        }
+
+        if (!prevId.isEmpty() && SortUtil::endDateTime(res) < SortUtil::endDateTime(prevRes)) {
+            continue;
+        }
+
+        prevId = id;
+        prevRes = res;
+    }
+
+    return prevId;
+}
+
 #include "moc_reservationhelper.cpp"
