@@ -11,6 +11,8 @@
 
 #include <utility>
 
+class ReservationManager;
+
 class QString;
 class QVariant;
 
@@ -35,10 +37,16 @@ public:
     [[nodiscard]] static bool isCancelled(const QVariant &res);
 
     /** Display label for a given reservation. */
-    [[nodiscard]] static QString label(const QVariant &res);
+    Q_INVOKABLE [[nodiscard]] static QString label(const QVariant &res);
 
     /** Default icon name for the given element. */
     Q_INVOKABLE [[nodiscard]] static QString defaultIconName(const QVariant &res);
+
+    /** Batch defining the location preceeding to @p resId.
+     *  That's usually ReservationManager::previousBatch, apart from nested
+     *  non-location change elements.
+     */
+    [[nodiscard]] static QString previousBatch(ReservationManager *resMgr, const QString &resId);
 };
 
 #endif // RESERVATIONHELPER_H
