@@ -9,6 +9,7 @@
 #include "jsonio.h"
 #include "logging.h"
 #include "transfer.h"
+#include "util.h"
 
 #include <KItinerary/SortUtil>
 
@@ -125,21 +126,7 @@ void TripGroup::store(const QString &path) const
 
 QString TripGroup::slugName() const
 {
-    QString s;
-    s.reserve(m_name.size());
-    for (const auto c : m_name) {
-        if (c.isLetter() || c.isDigit()) {
-            s.push_back(c.toCaseFolded());
-        } else if (!s.isEmpty() && s.back() != '-'_L1) {
-            s.push_back('-'_L1);
-        }
-    }
-
-    if (s.endsWith('-'_L1)) {
-        s.chop(1);
-    }
-
-    return s;
+    return Util::slugify(m_name);
 }
 
 QDateTime TripGroup::beginDateTime() const
