@@ -19,8 +19,11 @@ QJniObject Locale::fromLocale(const QLocale &locale)
     auto country = QJniObject::fromString(QLocale::territoryToString(locale.territory()));
     auto script = QJniObject::fromString(QLocale::scriptToString(locale.script()));
 
-    return QJniObject(Jni::typeName<java::util::Locale>(), (const char*)Jni::signature<void(java::lang::String, java::lang::String, java::lang::String)>(),
-        lang.object(), country.object(), script.object());
+    return QJniObject(Jni::typeName<java::util::Locale>(),
+                      (const char *)Jni::signature<void(java::lang::String, java::lang::String, java::lang::String)>(),
+                      lang.object(),
+                      country.object(),
+                      script.object());
 }
 
 QJniObject Locale::current()
