@@ -12,7 +12,8 @@
 class QJniObject;
 class QLocale;
 
-namespace KAndroidExtras {
+namespace KAndroidExtras
+{
 
 /** Conversion methods between java.util.Locale and QLocale.
  *  @note Do not rename this file to locale.h, that clashes with POSIX locale.h when your
@@ -20,11 +21,11 @@ namespace KAndroidExtras {
  */
 namespace Locale
 {
-    /** Create an java.util.Locale object from a QLocale. */
-    KANDROIDEXTRAS_EXPORT QJniObject fromLocale(const QLocale &locale);
+/** Create an java.util.Locale object from a QLocale. */
+KANDROIDEXTRAS_EXPORT QJniObject fromLocale(const QLocale &locale);
 
-    /** Create an java.util.Locale object for the current QLocale. */
-    KANDROIDEXTRAS_EXPORT QJniObject current();
+/** Create an java.util.Locale object for the current QLocale. */
+KANDROIDEXTRAS_EXPORT QJniObject current();
 }
 
 }
