@@ -6,10 +6,14 @@
 
 // list all headers here that have no .cpp file
 // this only serves as a guarantee that these headers actually compile
+#include "jniargument.h"
 #include "jniarray.h"
-#include "jnicommon.h"
 #include "jnimethod.h"
+#include "jniobject.h"
+#include "jnipp.h"
+#include "jniprimitivetypes.h"
 #include "jniproperty.h"
+#include "jnireturnvalue.h"
 #include "jnisignature.h"
 #include "jnitypes.h"
 #include "jnitypetraits.h"
